/*   This file is part of Xsltop.
*
*    Xsltop is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation.
*
*    Xsltop is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY.  See the
*    GNU General Public License for more details.
*
*    See <http://www.gnu.org/licenses/>.
*/
package xsltop.gui;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.io.File;

import javax.swing.JTextPane;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
/**
 * XSL editor is a JTextPane.
 * @author philippe voncken
 *
 */
public class XslEditor extends JTextPane 
implements DocumentListener, KeyListener {
	private File file = null;
	private boolean modified = false;
	/** . */
	private static final long serialVersionUID = -4176147480631540386L;
	/** To delegate the technical mecanism to Manager. */
	private GuiManager manager;
	private XslEditor() {
	}
	/**
	 * 
	 * @param label
	 */
	public XslEditor(GuiManager manager) {
		this();
		this.getDocument().addDocumentListener(this);
		this.addKeyListener(this);
		this.manager = manager;
		manager.setXslEditor(this);
	}
	/**
	 * the file getter.
	 * @return the file
	 */
	public File getFile() {
		return this.file;
	}
	/**
	 * the file setter.
	 * @param file to set
	 */
	public void setFile(File file) {
		this.file = file;
		Config config = Config.getInstance();
		config.setFilePath(file.getParent());
		config.saveConfig();
	}
	public void changedUpdate(DocumentEvent e) {
		//System.out.println("change update xml");		
	}
	public void insertUpdate(DocumentEvent e) {
		manager.changeXSL();
	}
	public void removeUpdate(DocumentEvent e) {
		manager.changeXSL();
	}
	public void keyPressed(KeyEvent e) {
		//System.out.println("keyReleased xml " + e.getKeyCode() + " modifier" + e.getModifiers());
		if (e.getModifiers() == 2) {
			if (e.getKeyCode() == 83) { // Ctr + S
				manager.saveXSL();
			}
		}
		this.getParent().getParent().setEnabled(false);
	}
	public void keyReleased(KeyEvent e) {
		//System.out.println("keyReleased xml " + e.getKeyCode());
	}
	public void keyTyped(KeyEvent e) {
		//System.out.println("keyTyped xml " + e.getKeyCode());
	}
	/**
	 * @return the modified
	 */
	public boolean isModified() {
		return modified;
	}
	/**
	 * @param modified the modified to set
	 */
	public void setModified(boolean modified) {
		this.modified = modified;
	}
}
